/// <reference types="ignite-ui" />
import { ElementRef, Renderer, IterableDiffers } from "@angular/core";
import { IgEditorBase } from "./igeditorbase";
import { NgModel } from "@angular/forms";
export declare class IgTextEditorComponent extends IgEditorBase<IgTextEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer, differs: IterableDiffers, model: NgModel);
    /**
     * Gets the visible text in the editor.
     */
    displayValue(): string;
    /**
     * Gets reference to jquery object which is used as container of drop-down list.
     */
    dropDownContainer(): string;
    /**
     * Shows the drop down list.
     */
    showDropDown(): void;
    /**
     * Hides the drop down list.
     */
    hideDropDown(): void;
    /**
     * Returns a reference to the drop-down button UI element of the editor.
     */
    dropDownButton(): string;
    /**
     * Returns if the drop-down list is visible.
     */
    dropDownVisible(): boolean;
    /**
     * Returns a reference to the clear button UI element of the editor.
     */
    clearButton(): string;
    /**
     * Finds index of list item by text that matches with the search parameters.
     *
     * @param text     The text to search for in the drop down list.
     * @param matchType     The rule that is applied for searching the text.
     */
    findListItemIndex(text: string, matchType?: Object): number;
    /**
     * Gets the index of the selected list item. Sets selected item by index.
     *
     * @param index     The index of the item that needs to be selected.
     */
    selectedListIndex(index?: number): number;
    /**
     * Gets the selected list item.
     */
    getSelectedListItem(): string;
    /**
     * Gets the selected text in the editor.
     */
    getSelectedText(): string;
    /**
     * Gets the start index of the selected text in the editor.
     */
    getSelectionStart(): number;
    /**
     * Gets the end index of the selected text in the editor.
     */
    getSelectionEnd(): number;
    /**
     * Inserts the text at the location of the caret or over the current selection. If the editor is focused the method will insert the text over the current selection. If the editor is not focused the method will set the text as value of the editor.
     * 				Note: The method raises [textChanged](ui.igtexteditor#events:textChanged) event.
     *
     * @param string     The string to be inserted.
     */
    insert(string: string): void;
    /**
     * Selects the text between start and end indices in the editor. If the parameters are equal, then the method sets location of caret. The method has effect only when the editor has focus.
     *
     * @param start     Start of the selection.
     * @param end     End of the selection.
     */
    select(start: number, end: number): void;
    /**
     * Hovers the previous item in the drop-down list if the list is opened.
     */
    spinUp(): void;
    /**
     * Hovers the next item in the drop-down list if the list is opened.
     */
    spinDown(): void;
    /**
     * Returns a reference to the spin up UI element of the editor.
     */
    spinUpButton(): string;
    /**
     * Returns a reference to the spin down UI element of the editor.
     */
    spinDownButton(): string;
}
