/// <reference types="ignite-ui" />
import { IgControlBase } from "../igcontrolbase/igcontrolbase";
import { ElementRef, Renderer, IterableDiffers } from "@angular/core";
export declare class IgPieChartComponent extends IgControlBase<IgPieChart> {
    constructor(el: ElementRef, renderer: Renderer, differs: IterableDiffers);
    option(): void;
    /**
     * Adds a new item to the data source and notifies the chart.
     *
     * @param item     the new item that will be added to the data source.
     */
    addItem(item: Object): void;
    /**
     * Inserts a new item to the data source and notifies the chart.
     *
     * @param item     the new item that will be inserted in the data source.
     * @param index     The index in the data source where the new item will be inserted.
     */
    insertItem(item: Object, index: number): void;
    /**
     * Deletes an item from the data source and notifies the chart.
     *
     * @param index     The index in the data source from where the item will be been removed.
     */
    removeItem(index: number): void;
    /**
     * Updates an item in the data source and notifies the chart.
     *
     * @param index     The index in the data source that we want to change.
     * @param item     the new item that we want to set in the data source.
     */
    setItem(index: number, item: Object): void;
    /**
     * Exports the chart to a PNG image.
     *
     * @param width     The width of the image.
     * @param height     The height of the image.
     */
    exportImage(width?: Object, height?: Object): Object;
    /**
     * Destroys the widget.
     */
    destroy(): void;
    /**
     * Returns the ID of parent element holding the chart.
     */
    id(): string;
    /**
     * Returns the element holding the chart.
     */
    widget(): void;
    /**
     * Creates a print preview page with the chart, hiding all other elements on the page.
     */
    print(): void;
    /**
     * Exports visual data from the pie chart to aid in unit testing
     */
    exportVisualData(): void;
}
